@@ -170,6 +170,7 @@ $form_list = (new CFormList())
 			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 			->setMaxLength(DB::getFieldLength('scripts', 'command'))
 			->setAriaRequired()
+			->disableSpellcheck()
 	)
 	->addRow((new CLabel(_('Command'), 'commandipmi'))->setAsteriskMark(),
 		(new CTextBox('commandipmi', $data['commandipmi'], false, DB::getFieldLength('scripts', 'command')))
@@ -255,7 +256,7 @@ $form_list
 	->addRow(new CLabel(_('Confirmation text'), 'confirmation'), [
 		(new CTextBox('confirmation', $data['confirmation'], false, DB::getFieldLength('scripts', 'confirmation')))
 			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH),
-		SPACE,
+		NBSP(),
 		(new CButton('testConfirmation', _('Test confirmation')))
 			->addClass(ZBX_STYLE_BTN_GREY)
 			->setId('test-confirmation')
