@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 class CSvgRect extends CSvgTag {
 
 	public function __construct($x, $y, $width, $height) {
-		parent::__construct('rect', true);
+		parent::__construct('rect');
 
 		$this->setAttribute('x', $x);
 		$this->setAttribute('y', $y);
