@@ -43,7 +43,7 @@
 
 	echo (new CListItem([
 		(new CDiv([
-			(new CDiv())->addClass(ZBX_STYLE_DRAG_ICON),
+			(new CDiv(new CVar('preprocessing[#{rowNum}][sortorder]', '#{sortorder}')))->addClass(ZBX_STYLE_DRAG_ICON),
 			(new CDiv($preproc_types_select))
 				->addClass('list-numbered-item')
 				->addClass('step-name'),
@@ -110,6 +110,26 @@
 	?>
 </script>
 
+<script type="text/x-jquery-tmpl" id="preprocessing-steps-parameters-custom-prometheus-pattern">
+	<?= (new CTextBox('preprocessing[#{rowNum}][params][0]', ''))
+			->setAttribute('placeholder', '#{placeholder_0}').
+		(new CSelect('preprocessing[#{rowNum}][params][1]'))
+			->addOptions(CSelect::createOptionsFromArray([
+				ZBX_PREPROC_PROMETHEUS_VALUE => _('value'),
+				ZBX_PREPROC_PROMETHEUS_LABEL => _('label'),
+				ZBX_PREPROC_PROMETHEUS_SUM => 'sum',
+				ZBX_PREPROC_PROMETHEUS_MIN => 'min',
+				ZBX_PREPROC_PROMETHEUS_MAX => 'max',
+				ZBX_PREPROC_PROMETHEUS_AVG => 'avg',
+				ZBX_PREPROC_PROMETHEUS_COUNT => 'count'
+			]))
+			->addClass('js-preproc-param-prometheus-pattern-function').
+		(new CTextBox('preprocessing[#{rowNum}][params][2]', ''))
+			->setAttribute('placeholder', '#{placeholder_2}')
+			->setEnabled(false)
+	?>
+</script>
+
 <script type="text/javascript">
 	jQuery(function($) {
 		function makeParameterInput(index, type) {
@@ -117,7 +137,10 @@
 				preproc_param_double_tmpl = new Template($('#preprocessing-steps-parameters-double-tmpl').html()),
 				preproc_param_custom_width_chkbox_tmpl =
 					new Template($('#preprocessing-steps-parameters-custom-width-chkbox-tmpl').html()),
-				preproc_param_multiline_tmpl = new Template($('#preprocessing-steps-parameters-multiline-tmpl').html());
+				preproc_param_multiline_tmpl = new Template($('#preprocessing-steps-parameters-multiline-tmpl').html()),
+				preproc_param_prometheus_pattern_tmpl = new Template(
+					$('#preprocessing-steps-parameters-custom-prometheus-pattern').html()
+				);
 
 			switch (type) {
 				case '<?= ZBX_PREPROC_MULTIPLIER ?>':
@@ -185,16 +208,16 @@
 						label_after: '}',
 						grow: 'auto',
 						rows: 0,
-						maxlength: <?= $data['preprocessing_script_maxlength'] ?>
+						maxlength: <?= DB::getFieldLength('item_preproc', 'params') ?>
 					});
 
 				case '<?= ZBX_PREPROC_PROMETHEUS_PATTERN ?>':
-					return $(preproc_param_double_tmpl.evaluate({
+					return $(preproc_param_prometheus_pattern_tmpl.evaluate({
 						rowNum: index,
 						placeholder_0: <?= json_encode(
 							_('<metric name>{<label name>="<label value>", ...} == <value>')
 						) ?>,
-						placeholder_1: <?= json_encode(_('<label name>')) ?>
+						placeholder_2: <?= json_encode(_('<label name>')) ?>
 					}));
 
 				case '<?= ZBX_PREPROC_PROMETHEUS_TO_JSON ?>':
@@ -229,8 +252,50 @@
 			}
 		}
 
-		var $preprocessing = $('#preprocessing'),
-			step_index = $preprocessing.find('li.sortable').length;
+		/**
+		 * Allow only one option with value "ZBX_PREPROC_VALIDATE_NOT_SUPPORTED" to be enabled.
+		 */
+		function updateTypeOptionsAvailability() {
+			const $preproc_steps = $('z-select[name^="preprocessing["][name$="[type]"]');
+			const $preproc_steps_ns = $preproc_steps
+				.filter((_index, {value}) => value != <?= ZBX_PREPROC_VALIDATE_NOT_SUPPORTED ?>);
+
+			if ($preproc_steps_ns.length == $preproc_steps.length) {
+				for (let select of $preproc_steps_ns) {
+					for (let option of select.getOptions()) {
+						option.disabled = false;
+					}
+				}
+				return;
+			}
+
+			for (let select of $preproc_steps_ns) {
+				for (let option of select.getOptions()) {
+					if (option.value == <?= ZBX_PREPROC_VALIDATE_NOT_SUPPORTED ?>) {
+						option.disabled = true;
+					}
+				}
+			}
+		}
+
+		var $preprocessing = $('#preprocessing');
+
+		if ($preprocessing.length === 0) {
+			const prep_elem = document.querySelector('#preprocessing-field');
+
+			if (!prep_elem) {
+				return false;
+			}
+
+			let obj = prep_elem;
+			if (prep_elem.tagName === 'SPAN') {
+				obj = prep_elem.originalObject;
+			}
+
+			$preprocessing = $(obj.querySelector('#preprocessing'));
+		}
+
+		let step_index = $preprocessing.find('li.sortable').length;
 
 		$preprocessing.sortable({
 			disabled: $preprocessing.find('div.<?= ZBX_STYLE_DRAG_ICON ?>').hasClass('<?= ZBX_STYLE_DISABLED ?>'),
@@ -240,34 +305,49 @@
 			cursor: 'grabbing',
 			handle: 'div.<?= ZBX_STYLE_DRAG_ICON ?>',
 			tolerance: 'pointer',
-			opacity: 0.6
+			opacity: 0.6,
+			update: function() {
+				let i = 0;
+
+				$(this).find('li.sortable').each(function() {
+					$(this).find('[name*="sortorder"]').val(i++);
+				});
+			}
 		});
 
+		const change_event = new CustomEvent('item.preprocessing.change');
+
 		$preprocessing
 			.on('click', '.element-table-add', function() {
-				var preproc_row_tmpl = new Template($('#preprocessing-steps-tmpl').html()),
-					$row = $(preproc_row_tmpl.evaluate({rowNum: step_index}));
-					type = $('z-select[name*="type"]', $row).val();
+				let sortable_count = $preprocessing.find('li.sortable').length;
+				const preproc_row_tmpl = new Template($('#preprocessing-steps-tmpl').html());
+				const $row = $(preproc_row_tmpl.evaluate({
+					rowNum: step_index,
+					sortorder: sortable_count++
+				}));
+				const type = $('z-select[name*="type"]', $row).val();
 
 				$('.step-parameters', $row).html(makeParameterInput(step_index, type));
 				$(this).closest('.preprocessing-list-foot').before($row);
 
 				$('.preprocessing-list-head').show();
 
-				var sortable_count = $preprocessing.find('li.sortable').length;
-
 				if (sortable_count == 1) {
 					$('#preproc_test_all').show();
 					$preprocessing
 						.sortable('disable')
-						.find('div.<?= ZBX_STYLE_DRAG_ICON ?>').addClass('<?= ZBX_STYLE_DISABLED ?>');
+						.find('div.<?= ZBX_STYLE_DRAG_ICON ?>')
+						.addClass('<?= ZBX_STYLE_DISABLED ?>');
 				}
 				else if (sortable_count > 1) {
 					$preprocessing
 						.sortable('enable')
-						.find('div.<?= ZBX_STYLE_DRAG_ICON ?>').removeClass('<?= ZBX_STYLE_DISABLED ?>');
+						.find('div.<?= ZBX_STYLE_DRAG_ICON ?>')
+						.removeClass('<?= ZBX_STYLE_DISABLED ?>');
 				}
 
+				$preprocessing[0].dispatchEvent(change_event);
+				updateTypeOptionsAvailability();
 				step_index++;
 			})
 			.on('click', '#preproc_test_all', function() {
@@ -289,7 +369,7 @@
 			.on('click', '.element-table-remove', function() {
 				$(this).closest('li.sortable').remove();
 
-				var sortable_count = $preprocessing.find('li.sortable').length;
+				const sortable_count = $preprocessing.find('li.sortable').length;
 
 				if (sortable_count == 0) {
 					$('#preproc_test_all').hide();
@@ -300,6 +380,17 @@
 						.sortable('disable')
 						.find('div.<?= ZBX_STYLE_DRAG_ICON ?>').addClass('<?= ZBX_STYLE_DISABLED ?>');
 				}
+
+				if (sortable_count > 0) {
+					let i = 0;
+
+					$preprocessing.find('li.sortable').each(function() {
+						$(this).find('[name*="sortorder"]').val(i++);
+					});
+				}
+
+				$preprocessing[0].dispatchEvent(change_event);
+				updateTypeOptionsAvailability();
 			})
 			.on('change', 'z-select[name*="type"]', function() {
 				var $row = $(this).closest('.preprocessing-list-item'),
@@ -321,12 +412,23 @@
 							.prop('checked', false)
 							.prop('disabled', true)
 							.trigger('change');
+						$row.find('[name*="[test]"]').prop('disabled', false);
+						break;
+
+					case '<?= ZBX_PREPROC_VALIDATE_NOT_SUPPORTED ?>':
+						$on_fail
+							.prop('checked', true)
+							.prop('disabled', true)
+							.trigger('change');
 						break;
 
 					default:
 						$on_fail.prop('disabled', false);
+						$row.find('[name*="[test]"]').prop('disabled', false);
 						break;
 				}
+
+				updateTypeOptionsAvailability();
 			})
 			.on('change', 'input[type="text"][name*="params"]', function() {
 				$(this).attr('title', $(this).val());
@@ -364,6 +466,9 @@
 						.attr('placeholder', <?= json_encode(_('error message')) ?>)
 						.show();
 				}
+			})
+			.on('change', '.js-preproc-param-prometheus-pattern-function', function() {
+				$(this).next('input').prop('disabled', $(this).val() !== '<?= ZBX_PREPROC_PROMETHEUS_LABEL ?>');
 			});
 	});
 </script>
